==> nextcloud-19.0.7.tgz: nextcloud/apps/workflowengine/l10n/en_GB.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "The given operator is invalid",
    "The given regular expression is invalid" : "The given regular expression is invalid",
    "The given file size is invalid" : "The given file size is invalid",
    "The given tag id is invalid" : "The given tag id is invalid",
    "The given IP range is invalid" : "The given IP range is invalid",
    "The given IP range is not valid for IPv4" : "The given IP range is not valid for IPv4",
    "The given IP range is not valid for IPv6" : "The given IP range is not valid for IPv6",
    "The given time span is invalid" : "The given time span is invalid",
    "The given start time is invalid" : "The given start time is invalid",
    "The given end time is invalid" : "The given end time is invalid",
    "The given group does not exist" : "The given group does not exist",
    "File" : "File",
    "Operation #%s does not exist" : "Operation #%s does not exist",
    "Operation %s does not exist" : "Operation %s does not exist",
    "Operation %s is invalid" : "Operation %s is invalid",
    "Check %s does not exist" : "Check %s does not exist",
    "Check %s is invalid" : "Check %s is invalid",
    "Check #%s does not exist" : "Check #%s does not exist",
    "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
    "Folder" : "Folder",
    "Images" : "Images",
    "No results" : "No results",
    "%s (invisible)" : "%s (invisible)",
    "%s (restricted)" : "%s (restricted)",
    "Predefined URLs" : "Predefined URLs",
    "Files WebDAV" : "Files WebDAV",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Cancel" : "Cancel",
    "Delete" : "Delete",
    "Save" : "Save",
    "Browse the app store" : "Browse the app store",
    "matches" : "matches",
    "does not match" : "does not match",
    "is" : "is",
    "is not" : "is not",
    "File name" : "File name",
    "File MIME type" : "File MIME type",
    "File size (upload)" : "File size (upload)",
    "less" : "less",
    "less or equals" : "less or equals",
    "greater or equals" : "greater or equals",
    "greater" : "greater",
    "Request remote address" : "Request remote address",
    "matches IPv4" : "matches IPv4",
    "does not match IPv4" : "does not match IPv4",
    "matches IPv6" : "matches IPv6",
    "does not match IPv6" : "does not match IPv6",
    "File system tag" : "File system tag",
    "is tagged with" : "is tagged with",
    "is not tagged with" : "is not tagged with",
    "Request URL" : "Request URL",
    "Request time" : "Request time",
    "between" : "between",
    "not between" : "not between",
    "Request user agent" : "Request user agent",
    "User group membership" : "User group membership",
    "is member of" : "is member of",
    "is not member of" : "is not member of"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/workflowengine/l10n/en_GB.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "The given operator is invalid",
    "The given regular expression is invalid" : "The given regular expression is invalid",
    "The given file size is invalid" : "The given file size is invalid",
    "The given tag id is invalid" : "The given tag id is invalid",
    "The given IP range is invalid" : "The given IP range is invalid",
    "The given IP range is not valid for IPv4" : "The given IP range is not valid for IPv4",
    "The given IP range is not valid for IPv6" : "The given IP range is not valid for IPv6",
    "The given time span is invalid" : "The given time span is invalid",
    "The given start time is invalid" : "The given start time is invalid",
    "The given end time is invalid" : "The given end time is invalid",
    "The given group does not exist" : "The given group does not exist",
    "File" : "File",
    "Operation #%s does not exist" : "Operation #%s does not exist",
    "Operation %s does not exist" : "Operation %s does not exist",
    "Operation %s is invalid" : "Operation %s is invalid",
    "Check %s does not exist" : "Check %s does not exist",
    "Check %s is invalid" : "Check %s is invalid",
    "Check #%s does not exist" : "Check #%s does not exist",
    "Check %s is invalid or does not exist" : "Check %s is invalid or does not exist",
    "Folder" : "Folder",
    "Images" : "Images",
    "No results" : "No results",
    "%s (invisible)" : "%s (invisible)",
    "%s (restricted)" : "%s (restricted)",
    "Predefined URLs" : "Predefined URLs",
    "Files WebDAV" : "Files WebDAV",
    "Android client" : "Android client",
    "iOS client" : "iOS client",
    "Desktop client" : "Desktop client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Cancel" : "Cancel",
    "Delete" : "Delete",
    "Save" : "Save",
    "matches" : "matches",
    "does not match" : "does not match",
    "is" : "is",
    "is not" : "is not",
    "File name" : "File name",
    "File MIME type" : "File MIME type",
    "File size (upload)" : "File size (upload)",
    "less" : "less",
    "less or equals" : "less or equals",
    "greater or equals" : "greater or equals",
    "greater" : "greater",
    "Request remote address" : "Request remote address",
    "matches IPv4" : "matches IPv4",
    "does not match IPv4" : "does not match IPv4",
    "matches IPv6" : "matches IPv6",
    "does not match IPv6" : "does not match IPv6",
    "File system tag" : "File system tag",
    "is tagged with" : "is tagged with",
    "is not tagged with" : "is not tagged with",
    "Request URL" : "Request URL",
    "Request time" : "Request time",
    "between" : "between",
    "not between" : "not between",
    "Request user agent" : "Request user agent",
    "User group membership" : "User group membership",
    "is member of" : "is member of",
    "is not member of" : "is not member of",
    "Browse the app store" : "Browse the app store"
},
"nplurals=2; plural=(n != 1);");
